MyImg :: Processing of micrographs
----------------------------------

* MyImg contains tools for the processing of microscopic images.
* The package is under development, but some basic tools do work.

Installation
------------
* Requirement: Python with sci-modules: numpy, matplotlib, pandas
* `pip install scikit-image` = additional package for image processing 
* `pip install myimg` = MyImg package itself (uses all packages above)

Quick start
-----------

* TODO

Documentation, help and examples
--------------------------------

* [PyPI](https://pypi.org/project/myimg) repository.
* [GitHub](https://github.com/mirekslouf/myimg) repository.
* [GitHub Pages](https://mirekslouf.github.io/myimg)
  with [documentation](https://mirekslouf.github.io/myimg/docs). 

Versions of MyImg
-----------------

* Version 0.1 = 1st draft, too complex, later completely re-written 
* Version 0.2 = 2nd draft, better concept; functions: cut, crop, label, scalebar
* Version 0.3 = TODO: montage, scalebar/stripes, description, border...
